@@ -1,11 +1,10 @@
 from __future__ import annotations
 
 from semantha_sdk.api.semantha_endpoint import SemanthaAPIEndpoint
-from semantha_sdk.model.diff import Diff as DiffDTO
-from semantha_sdk.model.schema.diff import DiffSchema
+from semantha_sdk.model.diff import Diff as DiffDTO, DiffSchema
 
 
-class Diff(SemanthaAPIEndpoint):
+class DiffEndpoint(SemanthaAPIEndpoint):
     """ Create diffs between two texts. """
 
     @property
