@@ -1,9 +1,9 @@
 from __future__ import annotations
 
-from semantha_sdk.api.current_user import CurrentUser
-from semantha_sdk.api.diff import Diff
-from semantha_sdk.api.domains import Domains, Domain
-from semantha_sdk.api.model import Model
+from semantha_sdk.api.current_user import CurrentUserEndpoint
+from semantha_sdk.api.diff import DiffEndpoint
+from semantha_sdk.api.domain import DomainsEndpoint
+from semantha_sdk.api.model import ModelEndpoint
 from semantha_sdk.api.semantha_endpoint import SemanthaAPIEndpoint
 from semantha_sdk.rest.rest_client import RestClient
 
@@ -20,27 +20,27 @@ class SemanthaAPI(SemanthaAPIEndpoint):
 
     def __init__(self, session: RestClient, parent_endpoint: str):
         super().__init__(session, parent_endpoint)
-        self.__current_user = CurrentUser(session, self._endpoint)
-        self.__diff = Diff(session, self._endpoint)
-        self.__domains = Domains(session, self._endpoint)
-        self.__model = Model(session, self._endpoint)
+        self.__current_user = CurrentUserEndpoint(session, self._endpoint)
+        self.__diff = DiffEndpoint(session, self._endpoint)
+        self.__domains = DomainsEndpoint(session, self._endpoint)
+        self.__model = ModelEndpoint(session, self._endpoint)
 
     @property
     def _endpoint(self):
         return self._parent_endpoint
 
     @property
-    def current_user(self) -> CurrentUser:
+    def current_user(self) -> CurrentUserEndpoint:
         return self.__current_user
 
     @property
-    def domains(self) -> Domain | Domains:
+    def domains(self) -> DomainsEndpoint:
         return self.__domains
 
     @property
-    def diff(self) -> Diff:
+    def diff(self) -> DiffEndpoint:
         return self.__diff
 
     @property
-    def model(self) -> Model:
+    def model(self) -> ModelEndpoint:
         return self.__model
