@@ -1,10 +1,12 @@
 from __future__ import annotations
 
 from dataclasses import dataclass
-from typing import Optional
+from typing import Optional, List, Dict
+
+from marshmallow_dataclass import class_schema
 
 from semantha_sdk.model.reference import Reference
-from semantha_sdk.model.semantha_entity import SemanthaModelEntity
+from semantha_sdk.model.semantha_entity import SemanthaModelEntity, SemanthaSchema
 from semantha_sdk.model.sentence import Sentence
 
 
@@ -13,11 +15,14 @@ class Paragraph(SemanthaModelEntity):
     id: str
     type: str
     text: str
-    sentences: Optional[list[Sentence]]
+    sentences: Optional[List[Sentence]]
     document_name: Optional[str]
-    references: Optional[list[Reference]]
-    context: dict[str, str]
-    comment: str
+    references: Optional[List[Reference]]
+    context: Optional[Dict[str, str]]
+    comment: Optional[str]
+
+
+ParagraphSchema = class_schema(Paragraph, base_schema=SemanthaSchema)
 
 
 @dataclass(frozen=True)
@@ -25,8 +30,8 @@ class PatchParagraph(SemanthaModelEntity):
     id: Optional[str]
     type: Optional[str]
     text: Optional[str]
-    sentences: Optional[list[Sentence]]
+    sentences: Optional[List[Sentence]]
     document_name: Optional[Optional[str]]
-    references: Optional[list[Reference]]
-    context: Optional[dict[str, str]]
+    references: Optional[List[Reference]]
+    context: Optional[Dict[str, str]]
     comment: Optional[str]
