@@ -1,22 +1,23 @@
 from abc import ABC
 from dataclasses import dataclass
-from typing import Union, Optional, Type
+from typing import Type
 
-from marshmallow import Schema, post_load
+from marshmallow import Schema
+import humps
 
 
 @dataclass(frozen=True)
 class SemanthaModelEntity(ABC):
     pass
 
+
 def with_entity(cls: Type[SemanthaModelEntity]):
     class WithEntity:
         _entity_class = cls
 
     return WithEntity
 
+
 class SemanthaSchema(Schema):
-    @post_load
-    def make_object(self, in_data, **kwargs):
-        if hasattr(self, "_entity_class"):
-            return self._entity_class(**in_data)
\ No newline at end of file
+    def on_bind_field(self, field_name, field_obj):
+        field_obj.data_key = humps.camelize(field_obj.data_key or field_name)
